# Generated by Django 3.2.4 on 2022-01-05 07:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mailer_integration", "0019_auto_20211210_1602"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscription",
            name="deleted",
            field=models.BooleanField(
                blank=True, default=False, editable=False, verbose_name="Deleted"
            ),
        ),
    ]
