# Generated by Django 3.2.4 on 2021-08-23 13:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mailer_integration", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="interest",
            name="external_id",
            field=models.CharField(default=None, max_length=50, unique=True),
            preserve_default=False,
        ),
    ]
