# Generated by Django 3.2.4 on 2021-10-05 14:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0019_alter_term_slug"),
    ]

    operations = [
        migrations.AddField(
            model_name="postal",
            name="valid_from",
            field=models.DateField(blank=True, null=True, verbose_name="Valid from"),
        ),
        migrations.AddField(
            model_name="postal",
            name="valid_to",
            field=models.DateField(blank=True, null=True, verbose_name="Valid to"),
        ),
    ]
